@@ -115,3 +115,25 @@ test_that("rsplit labels", {
   original_id <- rs[, grepl("^id", names(rs))]
   expect_equal(all_labs, original_id)
 })
+
+test_that("passing a polygon works correctly", {
+  skip_if_not(sf::sf_use_s2())
+  ames_sf <- sf::st_as_sf(
+    modeldata::ames,
+    coords = c("Longitude", "Latitude"), 
+    crs = 4326
+  )
+  ch <- sf::st_as_sfc(sf::st_bbox(ames_sf))
+
+  withr::with_seed(
+    123,
+    pts <- sf::st_sample(ch, 1000)
+  )
+  nndm_1 <- spatial_nndm_cv(ames_sf[1:100, ], pts)
+  attr(nndm_1, "prediction_sites") <- ch
+  withr::with_seed(
+    123,
+    nndm_2 <- spatial_nndm_cv(ames_sf[1:100, ], ch)
+  )
+  expect_identical(nndm_1, nndm_2)
+})
\ No newline at end of file
